Class: TonClient::Abi
- Includes:
- CommonInstanceHelpers
- Defined in:
- lib/everscale-client-ruby/Client/Abi.rb
Constant Summary collapse
- MODULE =
self.to_s.downcase.gsub(/^(.+::|)(\w+)$/, '\2').freeze
Instance Attribute Summary collapse
-
#context ⇒ Object
readonly
Returns the value of attribute context.
-
#monitor ⇒ Object
readonly
Returns the value of attribute monitor.
-
#request_id ⇒ Object
readonly
Returns the value of attribute request_id.
-
#requests ⇒ Object
readonly
Returns the value of attribute requests.
Instance Method Summary collapse
-
#attach_signature(payload, &block) ⇒ Object
INPUT: ParamsOfAttachSignature abi: Value - # # Contract ABI public_key: String - # # Public key encoded in
hex. -
#attach_signature_sync(payload) ⇒ Object
Sync.
-
#attach_signature_to_message_body(payload, &block) ⇒ Object
INPUT: ParamsOfAttachSignatureToMessageBody abi: Value - # # Contract ABI public_key: String - # # Public key.
-
#attach_signature_to_message_body_sync(payload) ⇒ Object
Sync.
-
#calc_function_id(payload, &block) ⇒ Object
INPUT: ParamsOfCalcFunctionId abi: Value - # # Contract ABI.
-
#calc_function_id_sync(payload) ⇒ Object
Sync.
-
#decode_account_data(payload, &block) ⇒ Object
INPUT: ParamsOfDecodeAccountData abi: Value - # # Contract ABI data: String - # # Data BOC or BOC handle allow_partial: Boolean<Optional> - # # Flag allowing partial BOC decoding when ABI doesn’t describe the full body BOC.
-
#decode_account_data_sync(payload) ⇒ Object
Sync.
-
#decode_boc(payload, &block) ⇒ Object
INPUT: ParamsOfDecodeBoc params: Array - # # Parameters to decode from BOC boc: String - # # Data BOC or BOC handle allow_partial: Boolean - RESPONSE: ResultOfDecodeBoc data: Value - # # Decoded data as a JSON structure.
-
#decode_boc_sync(payload) ⇒ Object
Sync.
-
#decode_initial_data(payload, &block) ⇒ Object
INPUT: ParamsOfDecodeInitialData abi: Value<Optional> - # # Contract ABI.
-
#decode_initial_data_sync(payload) ⇒ Object
Sync.
-
#decode_message(payload, &block) ⇒ Object
INPUT: ParamsOfDecodeMessage abi: Value - # # contract ABI message: String - # # Message BOC allow_partial: Boolean<Optional> - # # Flag allowing partial BOC decoding when ABI doesn’t describe the full body BOC.
-
#decode_message_body(payload, &block) ⇒ Object
INPUT: ParamsOfDecodeMessageBody abi: Value - # # Contract ABI used to decode.
-
#decode_message_body_sync(payload) ⇒ Object
Sync.
-
#decode_message_sync(payload) ⇒ Object
Sync.
-
#encode_account(payload, &block) ⇒ Object
INPUT: ParamsOfEncodeAccount state_init: StateInitSource - # # Source of the account state init.
-
#encode_account_sync(payload) ⇒ Object
Sync.
-
#encode_boc(payload, &block) ⇒ Object
INPUT: ParamsOfAbiEncodeBoc params: Array - # # Parameters to encode into BOC data: Value - # # Parameters and values as a JSON structure boc_cache: BocCacheType<Optional> - # # Cache type to put the result.
-
#encode_boc_sync(payload) ⇒ Object
Sync.
-
#encode_initial_data(payload, &block) ⇒ Object
INPUT: ParamsOfEncodeInitialData abi: Value<Optional> - # # Contract ABI initial_data: Value - # # List of initial values for contract’s static variables.
-
#encode_initial_data_sync(payload) ⇒ Object
Sync.
-
#encode_internal_message(payload, &block) ⇒ Object
INPUT: ParamsOfEncodeInternalMessage abi: Value<Optional> - # # Contract ABI.
-
#encode_internal_message_sync(payload) ⇒ Object
Sync.
-
#encode_message(payload, &block) ⇒ Object
INPUT: ParamsOfEncodeMessage abi: Value - # # Contract ABI.
-
#encode_message_body(payload, &block) ⇒ Object
INPUT: ParamsOfEncodeMessageBody abi: Value - # # Contract ABI.
-
#encode_message_body_sync(payload) ⇒ Object
Sync.
-
#encode_message_sync(payload) ⇒ Object
Sync.
-
#initialize(context: nil, request_id: nil, requests: nil, monitor: nil) ⇒ Abi
constructor
A new instance of Abi.
-
#update_initial_data(payload, &block) ⇒ Object
INPUT: ParamsOfUpdateInitialData abi: Value<Optional> - # # Contract ABI data: String - # # Data BOC or BOC handle initial_data: Value - # # List of initial values for contract’s static variables.
-
#update_initial_data_sync(payload) ⇒ Object
Sync.
Methods included from CommonInstanceHelpers
#base64?, #encode_to_base64, #full_method_name
Constructor Details
#initialize(context: nil, request_id: nil, requests: nil, monitor: nil) ⇒ Abi
Returns a new instance of Abi.
9 10 11 12 13 14 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 9 def initialize(context: nil, request_id: nil, requests: nil, monitor: nil) @context = context @request_id = request_id @requests = requests @monitor = monitor end |
Instance Attribute Details
#context ⇒ Object (readonly)
Returns the value of attribute context.
6 7 8 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 6 def context @context end |
#monitor ⇒ Object (readonly)
Returns the value of attribute monitor.
6 7 8 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 6 def monitor @monitor end |
#request_id ⇒ Object (readonly)
Returns the value of attribute request_id.
6 7 8 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 6 def request_id @request_id end |
#requests ⇒ Object (readonly)
Returns the value of attribute requests.
6 7 8 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 6 def requests @requests end |
Instance Method Details
#attach_signature(payload, &block) ⇒ Object
INPUT: ParamsOfAttachSignature abi: Value - # # Contract ABI public_key: String - # # Public key encoded in hex. message: String - # # Unsigned message BOC encoded in base64. signature: String - # # Signature encoded in hex. RESPONSE: ResultOfAttachSignature message: String - # # Signed message BOC message_id: String - # # Message ID Async
118 119 120 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 118 def attach_signature(payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#attach_signature_sync(payload) ⇒ Object
Sync
123 124 125 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 123 def attach_signature_sync(payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#attach_signature_to_message_body(payload, &block) ⇒ Object
INPUT: ParamsOfAttachSignatureToMessageBody abi: Value - # # Contract ABI public_key: String - # # Public key. # # Must be encoded with hex. message: String - # # Unsigned message body BOC. # # Must be encoded with base64. signature: String - # # Signature. # # Must be encoded with hex. RESPONSE: ResultOfAttachSignatureToMessageBody body: String - Async
49 50 51 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 49 def (payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#attach_signature_to_message_body_sync(payload) ⇒ Object
Sync
54 55 56 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 54 def (payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#calc_function_id(payload, &block) ⇒ Object
INPUT: ParamsOfCalcFunctionId abi: Value - # # Contract ABI. function_name: String - # # Contract function name output: Boolean<Optional> - # # If set to true output function ID will be returned which is used in contract response. Default is false RESPONSE: ResultOfCalcFunctionId function_id: Number - # # Contract function ID Async
292 293 294 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 292 def calc_function_id(payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#calc_function_id_sync(payload) ⇒ Object
Sync
297 298 299 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 297 def calc_function_id_sync(payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#decode_account_data(payload, &block) ⇒ Object
INPUT: ParamsOfDecodeAccountData abi: Value - # # Contract ABI data: String - # # Data BOC or BOC handle allow_partial: Boolean<Optional> - # # Flag allowing partial BOC decoding when ABI doesn’t describe the full body BOC. Controls decoder behaviour when after decoding all described in ABI params there are some data left in BOC: true - return decoded values false - return error of incomplete BOC deserialization (default) RESPONSE: ResultOfDecodeAccountData data: Value - # # Decoded data as a JSON structure. Async
192 193 194 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 192 def decode_account_data(payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#decode_account_data_sync(payload) ⇒ Object
Sync
197 198 199 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 197 def decode_account_data_sync(payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#decode_boc(payload, &block) ⇒ Object
INPUT: ParamsOfDecodeBoc params: Array - # # Parameters to decode from BOC boc: String - # # Data BOC or BOC handle allow_partial: Boolean - RESPONSE: ResultOfDecodeBoc data: Value - # # Decoded data as a JSON structure. Async
260 261 262 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 260 def decode_boc(payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#decode_boc_sync(payload) ⇒ Object
Sync
265 266 267 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 265 def decode_boc_sync(payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#decode_initial_data(payload, &block) ⇒ Object
INPUT: ParamsOfDecodeInitialData abi: Value<Optional> - # # Contract ABI. # # Initial data is decoded if this parameter is provided data: String - # # Data BOC or BOC handle allow_partial: Boolean<Optional> - # # Flag allowing partial BOC decoding when ABI doesn’t describe the full body BOC. Controls decoder behaviour when after decoding all described in ABI params there are some data left in BOC: true - return decoded values false - return error of incomplete BOC deserialization (default) RESPONSE: ResultOfDecodeInitialData initial_data: Value<Optional> - # # List of initial values of contract’s public variables. # # Initial data is decoded if abi input parameter is provided initial_pubkey: String - # # Initial account owner’s public key Async
244 245 246 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 244 def decode_initial_data(payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#decode_initial_data_sync(payload) ⇒ Object
Sync
249 250 251 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 249 def decode_initial_data_sync(payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#decode_message(payload, &block) ⇒ Object
INPUT: ParamsOfDecodeMessage abi: Value - # # contract ABI message: String - # # Message BOC allow_partial: Boolean<Optional> - # # Flag allowing partial BOC decoding when ABI doesn’t describe the full body BOC. Controls decoder behaviour when after decoding all described in ABI params there are some data left in BOC: true - return decoded values false - return error of incomplete BOC deserialization (default) RESPONSE: DecodedMessageBody body_type: MessageBodyType - # # Type of the message body content. name: String - # # Function or event name. value: Value<Optional> - # # Parameters or result value. header: FunctionHeader<Optional> - # # Function header. Async
137 138 139 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 137 def (payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#decode_message_body(payload, &block) ⇒ Object
INPUT: ParamsOfDecodeMessageBody abi: Value - # # Contract ABI used to decode. body: String - # # Message body BOC encoded in base64. is_internal: Boolean - # # True if the body belongs to the internal message. allow_partial: Boolean<Optional> - # # Flag allowing partial BOC decoding when ABI doesn’t describe the full body BOC. Controls decoder behaviour when after decoding all described in ABI params there are some data left in BOC: true - return decoded values false - return error of incomplete BOC deserialization (default) RESPONSE: DecodedMessageBody body_type: MessageBodyType - # # Type of the message body content. name: String - # # Function or event name. value: Value<Optional> - # # Parameters or result value. header: FunctionHeader<Optional> - # # Function header. Async
157 158 159 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 157 def (payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#decode_message_body_sync(payload) ⇒ Object
Sync
162 163 164 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 162 def (payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#decode_message_sync(payload) ⇒ Object
Sync
142 143 144 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 142 def (payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#encode_account(payload, &block) ⇒ Object
INPUT: ParamsOfEncodeAccount state_init: StateInitSource - # # Source of the account state init. balance: BigInt<Optional> - # # Initial balance. last_trans_lt: BigInt<Optional> - # # Initial value for the last_trans_lt. last_paid: Number<Optional> - # # Initial value for the last_paid. boc_cache: BocCacheType<Optional> - # # Cache type to put the result. # # The BOC itself returned if no cache type provided RESPONSE: ResultOfEncodeAccount account: String - # # Account BOC encoded in base64. id: String - # # Account ID encoded in hex. Async
176 177 178 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 176 def encode_account(payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#encode_account_sync(payload) ⇒ Object
Sync
181 182 183 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 181 def encode_account_sync(payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#encode_boc(payload, &block) ⇒ Object
INPUT: ParamsOfAbiEncodeBoc params: Array - # # Parameters to encode into BOC data: Value - # # Parameters and values as a JSON structure boc_cache: BocCacheType<Optional> - # # Cache type to put the result. # # The BOC itself returned if no cache type provided RESPONSE: ResultOfAbiEncodeBoc boc: String - # # BOC encoded as base64 Async
276 277 278 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 276 def encode_boc(payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#encode_boc_sync(payload) ⇒ Object
Sync
281 282 283 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 281 def encode_boc_sync(payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#encode_initial_data(payload, &block) ⇒ Object
INPUT: ParamsOfEncodeInitialData abi: Value<Optional> - # # Contract ABI initial_data: Value - # # List of initial values for contract’s static variables. # # abi parameter should be provided to set initial data initial_pubkey: String<Optional> - # # Initial account owner’s public key to set into account data boc_cache: BocCacheType<Optional> - # # Cache type to put the result. The BOC itself returned if no cache type provided. RESPONSE: ResultOfEncodeInitialData data: String - # # Updated data BOC or BOC handle Async
227 228 229 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 227 def encode_initial_data(payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#encode_initial_data_sync(payload) ⇒ Object
Sync
232 233 234 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 232 def encode_initial_data_sync(payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#encode_internal_message(payload, &block) ⇒ Object
INPUT: ParamsOfEncodeInternalMessage abi: Value<Optional> - # # Contract ABI. # # Can be None if both deploy_set and call_set are None. address: String<Optional> - # # Target address the message will be sent to. # # Must be specified in case of non-deploy message. src_address: String<Optional> - # # Source address of the message. deploy_set: DeploySet<Optional> - # # Deploy parameters. # # Must be specified in case of deploy message. call_set: CallSet<Optional> - # # Function call parameters. # # Must be specified in case of non-deploy message. In case of deploy message it is optional and contains parametersof the functions that will to be called upon deploy transaction. value: String - # # Value in nanotokens to be sent with message. bounce: Boolean<Optional> - # # Flag of bounceable message. # # Default is true. enable_ihr: Boolean<Optional> - # # Enable Instant Hypercube Routing for the message. # # Default is false. RESPONSE: ResultOfEncodeInternalMessage message: String - # # Message BOC encoded with base64. address: String - # # Destination address. message_id: String - # # Message id. Async
100 101 102 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 100 def (payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#encode_internal_message_sync(payload) ⇒ Object
Sync
105 106 107 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 105 def (payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#encode_message(payload, &block) ⇒ Object
INPUT: ParamsOfEncodeMessage abi: Value - # # Contract ABI. address: String<Optional> - # # Target address the message will be sent to. # # Must be specified in case of non-deploy message. deploy_set: DeploySet<Optional> - # # Deploy parameters. # # Must be specified in case of deploy message. call_set: CallSet<Optional> - # # Function call parameters. # # Must be specified in case of non-deploy message. In case of deploy message it is optional and contains parametersof the functions that will to be called upon deploy transaction. signer: Signer - # # Signing parameters. processing_try_index: Number<Optional> - # # Processing try index. # # Used in message processing with retries (if contract’s ABI includes “expire” header). Encoder uses the provided try index to calculate messageexpiration time. The 1st message expiration time is specified inClient config. Expiration timeouts will grow with every retry. Retry grow factor is set in Client config: <.….add config parameter with default value here>Default value is 0. RESPONSE: ResultOfEncodeMessage message: String - # # Message BOC encoded with base64. data_to_sign: String<Optional> - # # Optional data to be signed encoded in base64. # # Returned in case of Signer::External. Can be used for externalmessage signing. Is this case you need to use this data to create signature andthen produce signed message using abi.attach_signature. address: String - # # Destination address. message_id: String - # # Message id. Async
76 77 78 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 76 def (payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#encode_message_body(payload, &block) ⇒ Object
INPUT: ParamsOfEncodeMessageBody abi: Value - # # Contract ABI. call_set: CallSet - # # Function call parameters. # # Must be specified in non deploy message. In case of deploy message contains parameters of constructor. is_internal: Boolean - # # True if internal message body must be encoded. signer: Signer - # # Signing parameters. processing_try_index: Number<Optional> - # # Processing try index. # # Used in message processing with retries. Encoder uses the provided try index to calculate messageexpiration time. Expiration timeouts will grow with every retry. Default value is 0. address: String<Optional> - # # Destination address of the message # # Since ABI version 2.3 destination address of external inbound message is used in messagebody signature calculation. Should be provided when signed external inbound message body iscreated. Otherwise can be omitted. RESPONSE: ResultOfEncodeMessageBody body: String - # # Message body BOC encoded with base64. data_to_sign: String<Optional> - # # Optional data to sign. # # Encoded with base64. # Presents when message is unsigned. Can be used for externalmessage signing. Is this case you need to sing this data andproduce signed message using abi.attach_signature. Async
32 33 34 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 32 def (payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#encode_message_body_sync(payload) ⇒ Object
Sync
37 38 39 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 37 def (payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#encode_message_sync(payload) ⇒ Object
Sync
81 82 83 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 81 def (payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |
#update_initial_data(payload, &block) ⇒ Object
INPUT: ParamsOfUpdateInitialData abi: Value<Optional> - # # Contract ABI data: String - # # Data BOC or BOC handle initial_data: Value - # # List of initial values for contract’s static variables. # # abi parameter should be provided to set initial data initial_pubkey: String<Optional> - # # Initial account owner’s public key to set into account data boc_cache: BocCacheType<Optional> - # # Cache type to put the result. The BOC itself returned if no cache type provided. RESPONSE: ResultOfUpdateInitialData data: String - # # Updated data BOC or BOC handle Async
210 211 212 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 210 def update_initial_data(payload, &block) TonBinding.requestLibrary(context: context, request_id: request_id, requests: requests, monitor: monitor, method_name: full_method_name(MODULE, __method__.to_s), payload: payload, &block) end |
#update_initial_data_sync(payload) ⇒ Object
Sync
215 216 217 |
# File 'lib/everscale-client-ruby/Client/Abi.rb', line 215 def update_initial_data_sync(payload) TonBinding.send_request_sync(context: context, method_name: full_method_name(MODULE, __method__.to_s).sub(/_sync$/, ''), payload: payload) end |